==> aeneria-app-1.0.2.tar.gz: aeneria-app/src/Form/UserType.php <==
<?php

namespace App\Form;

use App\Entity\User;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\CallbackTransformer;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;

class UserType extends AbstractType
{
    private $passwordEncoder;

    public function __construct(UserPasswordEncoderInterface $passwordEncoder)
    {
        $this->passwordEncoder = $passwordEncoder;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $data = $builder->getData();

        $builder
            ->add('username', TextType::class, [
                'label' => 'Nom de l\'utilisateur',
            ])
            ->add('password', PasswordType::class, [
                'label' => 'Mot de passe',
                'always_empty' => false,
                'required' => !$data ?? false,
            ])
            ->add('is_admin', CheckboxType::class, [
                'label' => 'L\'utilisateur est Administrateur',
                'help' => 'S\'il est administrateur, il pourra ajouter/modifier/supprimer les autres utilisateurs',
                'required' => false,
            ])
            ->add('is_active', CheckboxType::class, [
                'label' => 'L\'utilisateur est actif',
                'required' => false,
            ])
            ->add('save', SubmitType::class, [
                'label' => 'Enregistrer',
            ])
            ->addModelTransformer(new CallbackTransformer(
                function (?User $user) {
                    if ($user) {
                        $data['user'] = $user;
                        $data['username'] = $user->getUsername();
                        $data['is_admin'] = \in_array(User::ROLE_ADMIN, $user->getRoles());
                        $data['is_active'] = $user->isActive();

                        return $data;
                    }
                },
                function (array $data) {
                    $user = $data['user'] ?? null;

                    if (!$user) {
                        $user = new User();
                    }

                    $user->setUsername($data['username']);
                    $user->setActive($data['is_active']);

                    if (\key_exists('password', $data) && $data['password']) {
                        $user->setPassword($this->passwordEncoder->encodePassword($user, $data['password']));
                    }

                    $user->setRoles($data['is_admin'] ? ['ROLE_ADMIN'] : []);

                    return $user;
                }
            ))
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
    }
}

==> aeneria-app-1.0.4.tar.gz: aeneria-app/src/Form/UserType.php <==
<?php

namespace App\Form;

use App\Entity\User;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\CallbackTransformer;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Symfony\Component\Validator\Constraints\Email;

class UserType extends AbstractType
{
    private $passwordEncoder;

    public function __construct(UserPasswordEncoderInterface $passwordEncoder)
    {
        $this->passwordEncoder = $passwordEncoder;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $data = $builder->getData();

        $builder
            ->add('username', EmailType::class, [
                'label' => 'Email',
                'constraints' => [new Email()],
            ])
            ->add('password', PasswordType::class, [
                'label' => 'Mot de passe',
                'always_empty' => false,
                'required' => !$data ?? false,
            ])
            ->add('is_admin', CheckboxType::class, [
                'label' => 'L\'utilisateur est Administrateur',
                'help' => 'S\'il est administrateur, il pourra ajouter/modifier/supprimer les autres utilisateurs',
                'required' => false,
            ])
            ->add('is_active', CheckboxType::class, [
                'label' => 'L\'utilisateur est actif',
                'required' => false,
            ])
            ->add('save', SubmitType::class, [
                'label' => 'Enregistrer',
            ])
            ->addModelTransformer(new CallbackTransformer(
                function (?User $user) {
                    if ($user) {
                        $data['user'] = $user;
                        $data['username'] = $user->getUsername();
                        $data['is_admin'] = \in_array(User::ROLE_ADMIN, $user->getRoles());
                        $data['is_active'] = $user->isActive();

                        return $data;
                    }
                },
                function (array $data) {
                    $user = $data['user'] ?? null;

                    if (!$user) {
                        $user = new User();
                    }

                    $user->setUsername($data['username']);
                    $user->setActive($data['is_active']);

                    if (\key_exists('password', $data) && $data['password']) {
                        $user->setPassword($this->passwordEncoder->encodePassword($user, $data['password']));
                    }

                    $user->setRoles($data['is_admin'] ? ['ROLE_ADMIN'] : []);

                    return $user;
                }
            ))
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
    }
}
